@@ -4,13 +4,7 @@
 <!--BEGIN STABILITY BANNER-->---
 
 
-![cdk-constructs: Experimental](https://img.shields.io/badge/cdk--constructs-experimental-important.svg?style=for-the-badge)
-
-> The APIs of higher level constructs in this module are experimental and under active development.
-> They are subject to non-backward compatible changes or removal in any future version. These are
-> not subject to the [Semantic Versioning](https://semver.org/) model and breaking changes will be
-> announced in the release notes. This means that while you may use them, you may need to update
-> your source code when upgrading to a newer version of this package.
+![cdk-constructs: Stable](https://img.shields.io/badge/cdk--constructs-stable-success.svg?style=for-the-badge)
 
 ---
 <!--END STABILITY BANNER-->
@@ -39,12 +33,10 @@ class InstanceIdTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.InstanceIdTarget",
 ):
-    '''(experimental) An EC2 instance that is the target for load balancing.
+    '''An EC2 instance that is the target for load balancing.
 
     If you register a target of this type, you are responsible for making
     sure the load balancer's security group can connect to the instance.
-
-    :stability: experimental
     '''
 
     def __init__(
@@ -52,12 +44,10 @@ class InstanceIdTarget(
         instance_id: builtins.str,
         port: typing.Optional[jsii.Number] = None,
     ) -> None:
-        '''(experimental) Create a new Instance target.
+        '''Create a new Instance target.
 
         :param instance_id: Instance ID of the instance to register to.
         :param port: Override the default port for the target group.
-
-        :stability: experimental
         '''
         jsii.create(InstanceIdTarget, self, [instance_id, port])
 
@@ -66,14 +56,12 @@ class InstanceIdTarget(
         self,
         target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
-        '''(experimental) Register this instance target with a load balancer.
+        '''Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
 
         :param target_group: -
-
-        :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToApplicationTargetGroup", [target_group]))
 
@@ -82,14 +70,12 @@ class InstanceIdTarget(
         self,
         target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
-        '''(experimental) Register this instance target with a load balancer.
+        '''Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
 
         :param target_group: -
-
-        :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
 
@@ -99,21 +85,15 @@ class InstanceTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.InstanceTarget",
 ):
-    '''
-    :stability: experimental
-    '''
-
     def __init__(
         self,
         instance: aws_cdk.aws_ec2.Instance,
         port: typing.Optional[jsii.Number] = None,
     ) -> None:
-        '''(experimental) Create a new Instance target.
+        '''Create a new Instance target.
 
         :param instance: Instance to register to.
         :param port: Override the default port for the target group.
-
-        :stability: experimental
         '''
         jsii.create(InstanceTarget, self, [instance, port])
 
@@ -123,7 +103,7 @@ class IpTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.IpTarget",
 ):
-    '''(experimental) An IP address that is a target for load balancing.
+    '''An IP address that is a target for load balancing.
 
     Specify IP addresses from the subnets of the virtual private cloud (VPC) for
     the target group, the RFC 1918 range (10.0.0.0/8, 172.16.0.0/12, and
@@ -132,8 +112,6 @@ class IpTarget(
 
     If you register a target of this type, you are responsible for making
     sure the load balancer's security group can send packets to the IP address.
-
-    :stability: experimental
     '''
 
     def __init__(
@@ -142,7 +120,7 @@ class IpTarget(
         port: typing.Optional[jsii.Number] = None,
         availability_zone: typing.Optional[builtins.str] = None,
     ) -> None:
-        '''(experimental) Create a new IPAddress target.
+        '''Create a new IPAddress target.
 
         The availabilityZone parameter determines whether the target receives
         traffic from the load balancer nodes in the specified Availability Zone
@@ -162,8 +140,6 @@ class IpTarget(
         :param ip_address: The IP Address to load balance to.
         :param port: Override the group's default port.
         :param availability_zone: Availability zone to send traffic from.
-
-        :stability: experimental
         '''
         jsii.create(IpTarget, self, [ip_address, port, availability_zone])
 
@@ -172,14 +148,12 @@ class IpTarget(
         self,
         target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
-        '''(experimental) Register this instance target with a load balancer.
+        '''Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
 
         :param target_group: -
-
-        :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToApplicationTargetGroup", [target_group]))
 
@@ -188,14 +162,12 @@ class IpTarget(
         self,
         target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
-        '''(experimental) Register this instance target with a load balancer.
+        '''Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
 
         :param target_group: -
-
-        :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
 
@@ -205,16 +177,10 @@ class LambdaTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.LambdaTarget",
 ):
-    '''
-    :stability: experimental
-    '''
-
     def __init__(self, fn: aws_cdk.aws_lambda.IFunction) -> None:
-        '''(experimental) Create a new Lambda target.
+        '''Create a new Lambda target.
 
         :param fn: -
-
-        :stability: experimental
         '''
         jsii.create(LambdaTarget, self, [fn])
 
@@ -223,14 +189,12 @@ class LambdaTarget(
         self,
         target_group: aws_cdk.aws_elasticloadbalancingv2.IApplicationTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
-        '''(experimental) Register this instance target with a load balancer.
+        '''Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
 
         :param target_group: -
-
-        :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToApplicationTargetGroup", [target_group]))
 
@@ -239,14 +203,12 @@ class LambdaTarget(
         self,
         target_group: aws_cdk.aws_elasticloadbalancingv2.INetworkTargetGroup,
     ) -> aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps:
-        '''(experimental) Register this instance target with a load balancer.
+        '''Register this instance target with a load balancer.
 
         Don't call this, it is called automatically when you add the target to a
         load balancer.
 
         :param target_group: -
-
-        :stability: experimental
         '''
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.LoadBalancerTargetProps, jsii.invoke(self, "attachToNetworkTargetGroup", [target_group]))
 
